pub struct ASI {
pub _01: String,
pub _02: E875,
pub _03: Option<E641>,
}Expand description
ASI - Action or Status Indicator
To indicate the action to be taken with the information provided or the status of an entity
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 306 | Action Code | 1 | M | ID | 1/2 |
| 02 | 875 | Maintenance Type Code | 1 | M | ID | 3/3 |
| 03 | 641 | Status Reason Code | 1 | O | ID | 3/3 |
Fields
_01: String_02: E875_03: Option<E641>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for ASI
impl<'de> Deserialize<'de> for ASI
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ASI
impl StructuralPartialEq for ASI