pub struct AT7 {
pub _01: Option<String>,
pub _02: Option<String>,
pub _03: Option<String>,
pub _04: Option<String>,
pub _05: Option<String>,
pub _06: Option<String>,
pub _07: Option<E623>,
}Expand description
AT7 - Shipment Status Details
To specify the status of a shipment
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 127 | Reference Identification | 1 | O | AN | 1/30 |
| 02 | 127 | Reference Identification | 1 | O | AN | 1/30 |
| 03 | 127 | Reference Identification | 1 | O | AN | 1/30 |
| 04 | 127 | Reference Identification | 1 | O | AN | 1/30 |
| 05 | 373 | Date | 1 | O | DT | 8/8 |
| 06 | 127 | Reference Identification | 1 | O | AN | 1/30 |
| 07 | 623 | Time Code | 1 | O | ID | 2/2 |
Fields
_01: Option<String>_02: Option<String>_03: Option<String>_04: Option<String>_05: Option<String>373 - Date
Date expressed as CCYYMMDD where CC represents the first two digits of the calendar year
- TYPE=DT
- MIN=8
- MAX=8
_06: Option<String>_07: Option<E623>623 - Time Code
Code identifying the time. In accordance with International Standards Organization standard 8601, time can be specified by a + or - and an indication in hours in relation to Universal Time Coordinate (UTC) time; since + is a restricted character, + and - are substituted by P and M in the codes that follow
- TYPE=ID
- MIN=2
- MAX=2