pub struct B4 {Show 13 fields
pub _01: Option<String>,
pub _02: Option<String>,
pub _03: Option<String>,
pub _04: Option<String>,
pub _05: Option<String>,
pub _06: Option<String>,
pub _07: Option<String>,
pub _08: Option<String>,
pub _09: Option<String>,
pub _10: Option<String>,
pub _11: Option<String>,
pub _12: Option<String>,
pub _13: Option<String>,
}Expand description
B4 - Beginning Segment for Inland Carriers
To transmit identifying numbers, dates, and other basic data relating to the shipment
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 152 | Special Handling Code | 1 | O | ID | 2/3 |
| 02 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 03 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 04 | 373 | Date | 1 | O | DT | 8/8 |
| 05 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 06 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 07 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 08 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 09 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 10 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 11 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 12 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
| 13 | 284 | Shipment Identification Number | 1 | O | AN | 1/30 |
Fields
_01: Option<String>152 - Special Handling Code
Code specifying special transportation handling instructions
- TYPE=ID
- MIN=2
- MAX=3
_02: Option<String>_03: Option<String>_04: Option<String>373 - Date
Date expressed as CCYYMMDD where CC represents the first two digits of the calendar year
- TYPE=DT
- MIN=8
- MAX=8
_05: Option<String>_06: Option<String>_07: Option<String>_08: Option<String>_09: Option<String>_10: Option<String>_11: Option<String>_12: Option<String>_13: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for B4
impl<'de> Deserialize<'de> for B4
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for B4
impl StructuralPartialEq for B4