pub struct BOL {
pub _01: String,
pub _02: String,
pub _03: String,
pub _04: String,
pub _05: Option<String>,
pub _06: Option<String>,
pub _07: Option<E160>,
pub _08: Option<E226>,
pub _09: Option<E501>,
pub _10: Option<String>,
pub _11: Option<String>,
}Expand description
BOL - Beginning Segment for the Motor Carrier Bill of Lading
To transmit identifying numbers, dates, and other basic data relating to the transaction set
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 140 | Standard Carrier Alpha Code | 1 | M | ID | 2/4 |
| 02 | 146 | Shipment Method of Payment | 1 | M | ID | 2/2 |
| 03 | 145 | Shipment Identification Number | 1 | M | AN | 1/30 |
| 04 | 373 | Date | 1 | M | DT | 8/8 |
| 05 | 337 | Time | 1 | O | TM | 4/8 |
| 06 | 127 | Reference Identification | 1 | O | AN | 1/50 |
| 07 | 160 | Status Report Request Code | 1 | O | ID | 1/1 |
| 08 | 226 | Section Seven Code | 1 | O | ID | 1/1 |
| 09 | 501 | Customs Documentation Handling Code | 1 | O | ID | 2/2 |
| 10 | 146 | Shipment Method of Payment | 1 | O | ID | 2/2 |
| 11 | 100 | Currency Code | 1 | O | ID | 3/3 |
Fields
_01: String_02: String_03: String_04: String_05: Option<String>_06: Option<String>_07: Option<E160>_08: Option<E226>_09: Option<E501>_10: Option<String>_11: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for BOL
impl<'de> Deserialize<'de> for BOL
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BOL
impl StructuralPartialEq for BOL