pub struct HPL {
pub _01: Option<String>,
pub _02: Option<String>,
pub _03: Option<E546>,
pub _04: Option<String>,
pub _05: Option<String>,
pub _06: Option<E83>,
}Expand description
HPL - Health Care Provider License
To provide license, certification, accreditation, and registration information for health care providers
| REF | ID | NAME | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|
| 01 | 128 | Reference Identification Qualifier | C | ID | 2/3 |
| 02 | 127 | Reference Identification | C | AN | 1/50 |
| 03 | 546 | Status Code | O | ID | 2/2 |
| 04 | 156 | State or Province Code | O | ID | 2/2 |
| 05 | 352 | Description | O | AN | 1/80 |
| 06 | 83 | Code For Licensing, Certification, Registration, or Accreditation Agency | C | ID | 1/2 |
Fields
_01: Option<String>_02: Option<String>_03: Option<E546>_04: Option<String>_05: Option<String>_06: Option<E83>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for HPL
impl<'de> Deserialize<'de> for HPL
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for HPL
impl StructuralPartialEq for HPL