Struct x12_types::v005010::ISA

source ·
pub struct ISA {
Show 16 fields pub _01: String, pub _02: String, pub _03: String, pub _04: String, pub _05: String, pub _06: String, pub _07: String, pub _08: String, pub _09: String, pub _10: String, pub _11: String, pub _12: String, pub _13: String, pub _14: String, pub _15: String, pub _16: String,
}
ISA - Interchange Control Header

To start and identify an interchange of zero or more functional groups and interchange-related control segments

REFIDNAMEREPEATREQTYPEMIN/MAX
01I01Authorization Information Qualifier1MID2/2
02I02Authorization Information1MAN10/10
03I03Security Information Qualifier1MID2/2
04I04Security Information1MAN10/10
05I05Interchange ID Qualifier1MID2/2
06I06Interchange Sender ID1MAN15/15
07I05Interchange ID Qualifier1MID2/2
08I07Interchange Receiver ID1MAN15/15
09I08Interchange Date1MDT6/6
10I09Interchange Time1MTM4/4
11I10Interchange Control Standards Identifier1MID1/1
12I11Interchange Control Version Number1MID5/5
13I12Interchange Control Number1MN09/9
14I13Acknowledgment Requested1MID1/1
15I14Usage Indicator1MID1/1
16I15Component Element Separator1M1/1

Fields

_01: String

I01 - Authorization Information Qualifier

Code to identify the type of information in the Authorization Information

  • TYPE=ID
  • MIN=2
  • MAX=2
_02: String

I02 - Authorization Information

Information used for additional identification or authorization of the interchange sender or the data in the interchange; the type of information is set by the Authorization Information Qualifier (I01)

  • TYPE=AN
  • MIN=10
  • MAX=10
_03: String

I03 - Security Information Qualifier

Code to identify the type of information in the Security Information

  • TYPE=ID
  • MIN=2
  • MAX=2
_04: String

I04 - Security Information

This is used for identifying the security information about the interchange sender or the data in the interchange; the type of information is set by the Security Information Qualifier (I03)

  • TYPE=AN
  • MIN=10
  • MAX=10
_05: String

I05 - Interchange ID Qualifier

Qualifier to designate the system/method of code structure used to designate the sender or receiver ID element being qualified

  • TYPE=ID
  • MIN=2
  • MAX=2
_06: String

I06 - Interchange Sender ID

Identification code published by the sender for other parties to use as the receiver ID to route data to them; the sender always codes this value in the sender ID element

  • TYPE=AN
  • MIN=15
  • MAX=15
_07: String

I05 - Interchange ID Qualifier

Qualifier to designate the system/method of code structure used to designate the sender or receiver ID element being qualified

  • TYPE=ID
  • MIN=2
  • MAX=2
_08: String

I07 - Interchange Receiver ID

Identification code published by the receiver of the data; When sending, it is used by the sender as their sending ID, thus other parties sending to them will use this as a receiving ID to route data to them

  • TYPE=AN
  • MIN=15
  • MAX=15
_09: String

I08 - Interchange Date

Date of the interchange

  • TYPE=DT
  • MIN=6
  • MAX=6
_10: String

I09 - Interchange Time

Time of the interchange

  • TYPE=TM
  • MIN=4
  • MAX=4
_11: String

I10 - Interchange Control Standards Identifier

Code to identify the agency responsible for the control standard used by the message that is enclosed by the interchange header and trailer

  • TYPE=ID
  • MIN=1
  • MAX=1
_12: String

I11 - Interchange Control Version Number

This version number covers the interchange control segments

  • TYPE=ID
  • MIN=5
  • MAX=5
_13: String

I12 - Interchange Control Number

A control number assigned by the interchange sender

  • TYPE=N0
  • MIN=9
  • MAX=9
_14: String

I13 - Acknowledgment Requested

Code sent by the sender to request an interchange acknowledgment (TA1)

  • TYPE=ID
  • MIN=1
  • MAX=1
_15: String

I14 - Usage Indicator

Code to indicate whether data enclosed by this interchange envelope is test, production or information

  • TYPE=ID
  • MIN=1
  • MAX=1
_16: String

I15 - Component Element Separator

Type is not applicable; the component element separator is a delimiter and not a data element; this field provides the delimiter used to separate component data elements within a composite data structure; this value must be different than the data element separator and the segment terminator

  • TYPE=
  • MIN=1
  • MAX=1