pub struct IT3 {
pub _01: Option<String>,
pub _02: Option<String>,
pub _03: Option<String>,
pub _04: Option<String>,
pub _05: Option<String>,
}Expand description
IT3 - Additional Item Data
To specify additional item details relating to variations between ordered and shipped quantities, or to specify alternate units of measures and quantities
Fields
_01: Option<String>_02: Option<String>_03: Option<String>_04: Option<String>_05: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for IT3
impl<'de> Deserialize<'de> for IT3
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for IT3
impl StructuralPartialEq for IT3