pub struct L3 {Show 15 fields
pub _01: Option<E81>,
pub _02: Option<String>,
pub _03: Option<E60>,
pub _04: Option<E122>,
pub _05: Option<E58>,
pub _06: Option<E191>,
pub _07: Option<E117>,
pub _08: Option<E150>,
pub _09: Option<E183>,
pub _10: Option<E184>,
pub _11: Option<E80>,
pub _12: Option<String>,
pub _13: Option<String>,
pub _14: Option<E74>,
pub _15: Option<E122>,
}Expand description
L3 - Total Weight and Charges
To specify the total shipment in terms of weight, volume, rates, charges, advances, and prepaid amounts applicable to one or more line items
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 81 | Weight | 1 | X | R | 1/10 |
| 02 | 187 | Weight Qualifier | 1 | X | ID | 1/2 |
| 03 | 60 | Freight Rate | 1 | X | R | 1/9 |
| 04 | 122 | Rate/Value Qualifier | 1 | X | ID | 2/2 |
| 05 | 58 | Charge | 1 | O/Z | N2 | 1/12 |
| 06 | 191 | Advances | 1 | O | N2 | 1/9 |
| 07 | 117 | Prepaid Amount | 1 | O | N2 | 1/9 |
| 08 | 150 | Special Charge or Allowance Code | 1 | O | ID | 3/3 |
| 09 | 183 | Volume | 1 | X | R | 1/8 |
| 10 | 184 | Volume Unit Qualifier | 1 | X | ID | 1/1 |
| 11 | 80 | Lading Quantity | 1 | O | N0 | 1/7 |
| 12 | 188 | Weight Unit Code | 1 | O | ID | 1/1 |
| 13 | 171 | Tariff Number | 1 | O | AN | 1/7 |
| 14 | 74 | Declared Value | 1 | X | N2 | 2/12 |
| 15 | 122 | Rate/Value Qualifier | 1 | X | ID | 2/2 |
Fields
_01: Option<E81>_02: Option<String>_03: Option<E60>_04: Option<E122>_05: Option<E58>_06: Option<E191>_07: Option<E117>_08: Option<E150>_09: Option<E183>_10: Option<E184>_11: Option<E80>_12: Option<String>_13: Option<String>_14: Option<E74>_15: Option<E122>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for L3
impl<'de> Deserialize<'de> for L3
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for L3
impl StructuralPartialEq for L3