pub struct LHT {
pub _01: Option<String>,
pub _02: Option<String>,
pub _03: Option<String>,
}Expand description
LHT - Transborder Hazardous Requirements
To specify the placard information required by the second government agency when shipment is to cross into another country
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 215 | Hazardous Classification | 1 | O | ID | 1/30 |
| 02 | 218 | Hazardous Placard Notation | 1 | O | ID | 14/40 |
| 03 | 222 | Hazardous Endorsement | 1 | O | ID | 4/25 |
Fields
_01: Option<String>_02: Option<String>_03: Option<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for LHT
impl<'de> Deserialize<'de> for LHT
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for LHT
impl StructuralPartialEq for LHT