pub struct MS1 {
pub _01: Option<String>,
pub _02: Option<String>,
pub _03: Option<String>,
pub _04: Option<String>,
pub _05: Option<String>,
pub _06: Option<E1280>,
pub _07: Option<E1280>,
}Expand description
MS1 - Equipment, Shipment, or Real Property Location
To specify the location of a piece of equipment, a shipment, or real property in terms of city and state or longitude and latitude
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 19 | City Name | 1 | X | AN | 2/30 |
| 02 | 156 | State or Province Code | 1 | X | ID | 2/2 |
| 03 | 26 | Country Code | 1 | X | ID | 2/3 |
| 04 | 1654 | Longitude Code | 1 | X/Z | ID | 7/7 |
| 05 | 1655 | Latitude Code | 1 | X/Z | ID | 7/7 |
| 06 | 1280 | Direction Identifier Code NEW | 1 | O/Z | ID | 1/1 |
| 07 | 1280 | Direction Identifier Code NEW | 1 | O/Z | ID | 1/1 |
Fields
_01: Option<String>19 - City Name
Free-form text for city name
- TYPE=AN
- MIN=2
- MAX=30
_02: Option<String>_03: Option<String>26 - Country Code
Code identifying the country
- TYPE=ID
- MIN=2
- MAX=3
_04: Option<String>_05: Option<String>_06: Option<E1280>_07: Option<E1280>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for MS1
impl<'de> Deserialize<'de> for MS1
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for MS1
impl StructuralPartialEq for MS1