pub struct REF {
pub _01: E128,
pub _02: Option<String>,
pub _03: Option<String>,
pub _04: Option<String>,
}Expand description
REF - Reference Information
To specify identifying information
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | 128 | Reference Identification Qualifier | 1 | M | ID | 2/3 |
| 02 | 127 | Reference Identification | 1 | M | AN | 1/50 |
| 03 | 352 | Description | 1 | O | AN | 1/80 |
| 04 | C040 | Reference Identifier | 1 | O | C | 1/1 |
Fields
_01: E128128 - Reference Identification Qualifier
_02: Option<String>127 - Reference Identification
Reference information as defined for a particular Transaction Set or as specified by the Reference Identification Qualifier
- TYPE=AN
- MIN=1
- MAX=50
_03: Option<String>352 - Description
A free-form description to clarify the related data elements and their content
- TYPE=AN
- MIN=1
- MAX=80
_04: Option<String>C040 - Reference Identifier
To identify one or more areas of the Reference Identifier
- TYPE=C
- MIN=1
- MAX=1