pub struct ISA {}Expand description
ISA - Interchange Control Header
To start and identify an interchange of zero or more functional groups and interchange-related control segments
| REF | ID | NAME | REPEAT | REQ | TYPE | MIN/MAX |
|---|---|---|---|---|---|---|
| 01 | I01 | Authorization Information Qualifier | 1 | M | ID | 2/2 |
| 02 | I02 | Authorization Information | 1 | M | AN | 10/10 |
| 03 | I03 | Security Information Qualifier | 1 | M | ID | 2/2 |
| 04 | I04 | Security Information | 1 | M | AN | 10/10 |
| 05 | I05 | Interchange ID Qualifier | 1 | M | ID | 2/2 |
| 06 | I06 | Interchange Sender ID | 1 | M | AN | 15/15 |
| 07 | I05 | Interchange ID Qualifier | 1 | M | ID | 2/2 |
| 08 | I07 | Interchange Receiver ID | 1 | M | AN | 15/15 |
| 09 | I08 | Interchange Date | 1 | M | DT | 6/6 |
| 10 | I09 | Interchange Time | 1 | M | TM | 4/4 |
| 11 | I10 | Interchange Control Standards Identifier | 1 | M | ID | 1/1 |
| 12 | I11 | Interchange Control Version Number | 1 | M | ID | 5/5 |
| 13 | I12 | Interchange Control Number | 1 | M | N0 | 9/9 |
| 14 | I13 | Acknowledgment Requested | 1 | M | ID | 1/1 |
| 15 | I14 | Usage Indicator | 1 | M | ID | 1/1 |
| 16 | I15 | Component Element Separator | 1 | M | 1/1 |
Fields
_01: StringI01 - Authorization Information Qualifier
Code to identify the type of information in the Authorization Information
- TYPE=ID
- MIN=2
- MAX=2
_02: StringI02 - Authorization Information
Information used for additional identification or authorization of the interchange sender or the data in the interchange; the type of information is set by the Authorization Information Qualifier (I01)
- TYPE=AN
- MIN=10
- MAX=10
_03: StringI03 - Security Information Qualifier
Code to identify the type of information in the Security Information
- TYPE=ID
- MIN=2
- MAX=2
_04: StringI04 - Security Information
This is used for identifying the security information about the interchange sender or the data in the interchange; the type of information is set by the Security Information Qualifier (I03)
- TYPE=AN
- MIN=10
- MAX=10
_05: StringI05 - Interchange ID Qualifier
Qualifier to designate the system/method of code structure used to designate the sender or receiver ID element being qualified
- TYPE=ID
- MIN=2
- MAX=2
_06: StringI06 - Interchange Sender ID
Identification code published by the sender for other parties to use as the receiver ID to route data to them; the sender always codes this value in the sender ID element
- TYPE=AN
- MIN=15
- MAX=15
_07: StringI05 - Interchange ID Qualifier
Qualifier to designate the system/method of code structure used to designate the sender or receiver ID element being qualified
- TYPE=ID
- MIN=2
- MAX=2
_08: StringI07 - Interchange Receiver ID
Identification code published by the receiver of the data; When sending, it is used by the sender as their sending ID, thus other parties sending to them will use this as a receiving ID to route data to them
- TYPE=AN
- MIN=15
- MAX=15
_09: StringI08 - Interchange Date
Date of the interchange
- TYPE=DT
- MIN=6
- MAX=6
_10: StringI09 - Interchange Time
Time of the interchange
- TYPE=TM
- MIN=4
- MAX=4
_11: StringI10 - Interchange Control Standards Identifier
Code to identify the agency responsible for the control standard used by the message that is enclosed by the interchange header and trailer
- TYPE=ID
- MIN=1
- MAX=1
_12: StringI11 - Interchange Control Version Number
This version number covers the interchange control segments
- TYPE=ID
- MIN=5
- MAX=5
_13: StringI12 - Interchange Control Number
A control number assigned by the interchange sender
- TYPE=N0
- MIN=9
- MAX=9
_14: StringI13 - Acknowledgment Requested
Code sent by the sender to request an interchange acknowledgment (TA1)
- TYPE=ID
- MIN=1
- MAX=1
_15: StringI14 - Usage Indicator
Code to indicate whether data enclosed by this interchange envelope is test, production or information
- TYPE=ID
- MIN=1
- MAX=1
_16: StringI15 - Component Element Separator
Type is not applicable; the component element separator is a delimiter and not a data element; this field provides the delimiter used to separate component data elements within a composite data structure; this value must be different than the data element separator and the segment terminator
- TYPE=
- MIN=1
- MAX=1